var NAVTREEINDEX6 =
{
"namespacemembers_func.html":[2,1,1],
"namespacemembers_vars.html":[2,1,2],
"namespaces.html":[2,0],
"pages.html":[],
"struct_c_d_s_rest_data_provider_1_1_query_operator_info.html":[3,0,0,0],
"struct_c_d_s_rest_data_provider_1_1_query_operator_info.html#a12c37a84d954151567af9f445b3fdf07":[3,0,0,0,1],
"struct_c_d_s_rest_data_provider_1_1_query_operator_info.html#a8806b2ba968610a7934c62ec599be600":[3,0,0,0,0]
};
